@@ -4,7 +4,7 @@ import bs4
 
 from ..boxes import Thumbnail
 from ..enums import ThumbnailType
-from ..utils import get_page, get_page_type
+from ..utils import LOGGER, get_page, get_page_type, join
 from . import opinion
 
 
@@ -35,9 +35,8 @@ class FrontPage:
     files : List[Thumbnail]
         A list of file like thumbnail objects representing the suggested
         files on the front page.
-    poll : Poll
-        The current ongoing moddb poll. Currently cannot be voted on.
-
+    poll_url : str
+        The url to the poll on the front page
     """
 
     def __init__(self, html: bs4.BeautifulSoup):
@@ -55,12 +54,20 @@ class FrontPage:
             elif "data-bg" in x.div:
                 image = x.div["data-bg"]
 
+            try:
+                page_type = get_page_type(x.a["href"])
+            except IndexError:
+                LOGGER.warning(
+                    "Unabled to get page type from %s for front page, skipping", x.a["href"]
+                )
+                continue
+
             thumbnail = Thumbnail(
                 name=name.string if name else None,
                 url=x.a["href"],
                 summary=summary.string if summary else None,
                 image=image,
-                type=get_page_type(x.a["href"]),
+                type=page_type,
             )
 
             self.slider.append(thumbnail)
@@ -141,9 +148,31 @@ class FrontPage:
             for x in files
         ]
 
-        self.poll = opinion.Poll(get_page(html.find("div", class_="poll").form["action"]))
+        try:
+            # maybe they haven't voted yet and the vote bar is there
+            self.poll_url = html.find("div", class_="poll").form["action"]
+        except AttributeError:
+            # maybe they've already voted and the result link is there
+            self.poll_url = join(
+                html.find("div", class_="poll").find("a", class_="results")["href"]
+            )
 
         self._html = html
+        self._poll = None
 
     def __repr__(self):
         return f"<FrontPage articles={len(self.articles)} mods={len(self.mods)} games={len(self.games)} files={len(self.files)}>"
+
+    def get_poll(self) -> opinion.Poll:
+        """Get the full item of the front page poll. This
+        result is cached after the first call.
+
+        Returns
+        --------
+        Poll
+            The returned poll
+        """
+        if self._poll is None:
+            self._poll = opinion.Poll(get_page(self.poll_url))
+
+        return self._poll
